@@ -20,14 +20,18 @@ GDSClassesMapping = {
     'exampleUri': uri,
     'equivalence': ConceptMapEquivalence,
     'referenceResource': ResourceReference,
+    'DigestMethod': DigestMethodType,
     'bornPeriod': Period,
+    'KeyValue': KeyValueType,
     'exampleRatio': Ratio,
     'ingredient': Substance_Ingredient,
+    'updated': DateTimeType,
     'lowerLimit': decimal,
     'dispense': Supply_Dispense,
     'sopclass': oid,
     'reasonResource': ResourceReference,
     'choice': Coding,
+    'Signature': SignatureType,
     'refusedIndicator': boolean,
     'maxLength': integer,
     'dischargeDiagnosis': ResourceReference,
@@ -39,7 +43,9 @@ GDSClassesMapping = {
     'additionalInstructions': CodeableConcept,
     'item': ResourceReference,
     'valueRatio': Ratio,
+    'Transforms': TransformsType,
     'answerString': string,
+    'XPath': string,
     'requirements': string,
     'numberOfInstances': integer,
     'dataInstant': instant,
@@ -47,6 +53,7 @@ GDSClassesMapping = {
     'asNeededCodeableConcept': CodeableConcept,
     'dataAttachment': Attachment,
     'section': Composition_Section,
+    'X509Certificate': base64Binary,
     'version': string,
     'emptyReason': CodeableConcept,
     'nameReference': string,
@@ -67,7 +74,9 @@ GDSClassesMapping = {
     'substance': ResourceReference,
     'remarks': string,
     'amount': Quantity,
+    'published': DateTimeType,
     'action': SecurityEventAction,
+    'SPKISexp': base64Binary,
     'options': ResourceReference,
     'answerDate': date,
     'dateAsserted': date,
@@ -75,6 +84,7 @@ GDSClassesMapping = {
     'diagnosticDateTime': dateTime,
     'confidentiality': CodeableConcept,
     'family': string,
+    'PGPData': PGPDataType,
     'clinicalNotes': string,
     'codedDiagnosis': CodeableConcept,
     'exampleDate': date,
@@ -126,6 +136,7 @@ GDSClassesMapping = {
     'dataInteger': integer,
     'attachment': ResourceReference,
     'doseTarget': CodeableConcept,
+    'X509IssuerName': string,
     'parameter': Extension,
     'profile': uri,
     'map': string,
@@ -140,6 +151,7 @@ GDSClassesMapping = {
     'participant': SecurityEvent_Participant,
     'data': ResourceReference,
     'response': Query_Response,
+    'X509CRL': base64Binary,
     'organization': ResourceReference,
     'object': SecurityEvent_Object,
     'documentation': string,
@@ -161,6 +173,7 @@ GDSClassesMapping = {
     'valueCodeableConcept': CodeableConcept,
     'group': Questionnaire_Group,
     'searchInclude': string,
+    'KeyName': string,
     'valueBoolean': boolean,
     'latitude': decimal,
     'conformance': BindingConformance,
@@ -170,6 +183,7 @@ GDSClassesMapping = {
     'timestamp': instant,
     'primary': boolean,
     'valueRange': Range,
+    'RSAKeyValue': RSAKeyValueType,
     'requestDetail': ResourceReference,
     'accomodation': Encounter_Accomodation,
     'valueId': id,
@@ -189,7 +203,7 @@ GDSClassesMapping = {
     'operation': Conformance_Operation,
     'collector': ResourceReference,
     'event': SecurityEvent_Event,
-    'category': MessageSignificanceCategory,
+    'category': CategoryType,
     'managingOrganization': ResourceReference,
     'container': Specimen_Container,
     'network': SecurityEvent_Network,
@@ -200,6 +214,7 @@ GDSClassesMapping = {
     'contained': Resource_Inline,
     'issue': OperationOutcome_Issue,
     'model': string,
+    'KeyInfo': KeyInfoType,
     'valueContact': Contact,
     'reason': CodeableConcept,
     'seriesDoses': integer,
@@ -212,10 +227,13 @@ GDSClassesMapping = {
     'qualification': Practitioner_Qualification,
     'first': Extension,
     'onsetDate': date,
+    'MgmtData': string,
     'suffix': string,
+    'X509Data': X509DataType,
     'isExtensible': boolean,
     'coding': Coding,
     'number': integer,
+    'RetrievalMethod': RetrievalMethodType,
     'bodySite': CodeableConcept,
     'owner': ResourceReference,
     'discriminator': id,
@@ -266,6 +284,7 @@ GDSClassesMapping = {
     'fhirVersion': id,
     'dataCode': code,
     'denominator': Quantity,
+    'Manifest': ManifestType,
     'vaccinationProtocol': Immunization_VaccinationProtocol,
     'position': Location_Position,
     'device': ResourceReference,
@@ -277,12 +296,14 @@ GDSClassesMapping = {
     'url': uri,
     'attester': Composition_Attester,
     'request': ResourceReference,
+    'uri': UriType,
     'quantity': Quantity,
     'exampleQuantity': Quantity,
     'refusalReason': CodeableConcept,
     'text': string,
     'supercedes': ResourceReference,
     'isBrand': boolean,
+    'X509IssuerSerial': X509IssuerSerialType,
     'relation': FamilyHistory_Relation,
     'dataDate': date,
     'availability': InstanceAvailability,
@@ -290,9 +311,10 @@ GDSClassesMapping = {
     'admitSource': CodeableConcept,
     'deceasedDateTime': dateTime,
     'copyright': string,
-    'title': string,
+    'title': TextType,
     'implementation': Conformance_Implementation,
     'valueCode': code,
+    'X509SerialNumber': integer,
     'factor': decimal,
     'diagnosticPeriod': Period,
     'doseStatus': CodeableConcept,
@@ -305,12 +327,14 @@ GDSClassesMapping = {
     'resource': Conformance_Resource,
     'dataString': string,
     'dateCriterion': ImmunizationRecommendation_DateCriterion,
-    'summary': CodeableConcept,
+    'summary': TextType,
     'subtype': CodeableConcept,
+    'SignedInfo': SignedInfoType,
     'activity': CarePlan_Activity,
     'view': CodeableConcept,
     'reference': ResourceReference,
     'exampleAttachment': Attachment,
+    'SignatureMethod': SignatureMethodType,
     'individual': ResourceReference,
     'result': ResourceReference,
     'interpreter': ResourceReference,
@@ -327,15 +351,18 @@ GDSClassesMapping = {
     'multipleBirthBoolean': boolean,
     'import': uri,
     'exampleInstant': instant,
+    'PGPKeyPacket': base64Binary,
     'valueHumanName': HumanName,
     'exampleDecimal': decimal,
     'valueDate': date,
+    'SignatureProperty': SignaturePropertyType,
     'valueSampledData': SampledData,
     'reaction': Immunization_Reaction,
     'whenPrepared': Period,
     'prescription': ResourceReference,
     'country': string,
     'responsibleParty': ResourceReference,
+    'Object': ObjectType,
     'context': string,
     'receiver': ResourceReference,
     'experimental': boolean,
@@ -380,13 +407,16 @@ GDSClassesMapping = {
     'metric': DeviceObservationReport_Metric,
     'binding': Profile_Binding,
     'site': string,
+    'PGPKeyID': base64Binary,
     'numberOfSeries': integer,
     'valueResource': ResourceReference,
     'asNeededBoolean': boolean,
+    'id': IdType,
+    'feed': FeedType,
     'reasonCodeableConcept': CodeableConcept,
     'bornString': string,
     'severity': ConstraintSeverity,
-    'author': ResourceReference,
+    'author': PersonType,
     'media': Coding,
     'authorizingPrescription': ResourceReference,
     'member': ResourceReference,
@@ -399,6 +429,8 @@ GDSClassesMapping = {
     'purpose': string,
     'identity': id,
     'slicing': Profile_Slicing,
+    'CanonicalizationMethod': CanonicalizationMethodType,
+    'X509SKI': base64Binary,
     'forecastStatus': CodeableConcept,
     'imagingStudy': ResourceReference,
     'dataDecimal': decimal,
@@ -407,7 +439,7 @@ GDSClassesMapping = {
     'extensible': boolean,
     'prescriber': ResourceReference,
     'doseSequence': integer,
-    'entry': List_Entry,
+    'entry': EntryType,
     'vaccineType': CodeableConcept,
     'maritalStatus': CodeableConcept,
     'protocol': ImmunizationRecommendation_Protocol,
@@ -431,16 +463,19 @@ GDSClassesMapping = {
     'serviceProvider': ResourceReference,
     'specimen': ResourceReference,
     'aggregation': AggregationMode,
+    'Transform': TransformType,
     'asserter': ResourceReference,
     'recipient': ResourceReference,
     'preAdmissionIdentifier': Identifier,
     'doseNumber': integer,
     'formal': string,
+    'X509SubjectName': string,
     'referenceUri': uri,
     'substitution': MedicationPrescription_Substitution,
     'dateTime': instant,
     'referenceRange': Observation_ReferenceRange,
     'indication': CodeableConcept,
+    'SignatureProperties': SignaturePropertiesType,
     'security': Conformance_Security,
     'deviceName': string,
     'deceasedAge': Age,
@@ -449,6 +484,7 @@ GDSClassesMapping = {
     'include': ValueSet_Include,
     'recommendation': ImmunizationRecommendation_Recommendation,
     'duration': decimal,
+    'SignatureValue': SignatureValueType,
     'dataRatio': Ratio,
     'dimensions': integer,
     'altId': string,
@@ -483,6 +519,7 @@ GDSClassesMapping = {
     'numberOfRepeatsAllowed': integer,
     'valueQuantity': Quantity,
     'messaging': Conformance_Messaging,
+    'Reference': ReferenceType,
     'software': string,
     'contains': ValueSet_Contains,
     'communication': CodeableConcept,
@@ -501,10 +538,11 @@ GDSClassesMapping = {
     'form': CodeableConcept,
     'specialty': CodeableConcept,
     'authenticator': ResourceReference,
-    'link': Patient_Link,
+    'link': linkType,
     'related': Observation_Related,
     'docStatus': CodeableConcept,
     'line': string,
+    'DSAKeyValue': DSAKeyValueType,
     'count': integer,
     'careProvider': ResourceReference,
     'characteristic': Group_Characteristic,
@@ -528,6 +566,7 @@ GDSClassesMapping = {
     'deceasedRange': Range,
     'orderer': ResourceReference,
     'reliability': ObservationReliability,
+    'SPKIData': SPKIDataType,
     'exampleHumanName': HumanName,
     'valueOid': oid,
     'virtualDevice': DeviceObservationReport_VirtualDevice,
@@ -560,7 +599,6 @@ GDSClassesMapping = {
     'receivedTime': dateTime,
 }
 
-
 def get_root_tag(node):
     tag = Tag_pattern_.match(node.tag).groups()[-1]
     rootClass = GDSClassesMapping.get(tag)
@@ -667,6 +705,7 @@ __all__ = [
     "Binary",
     "BindingConformance",
     "Block",
+    "CanonicalizationMethodType",
     "CarePlan",
     "CarePlanActivityCategory",
     "CarePlanActivityStatus",
@@ -676,6 +715,7 @@ __all__ = [
     "CarePlan_Goal",
     "CarePlan_Participant",
     "CarePlan_Simple",
+    "CategoryType",
     "CausalityExpectation",
     "CodeableConcept",
     "Coding",
@@ -717,8 +757,11 @@ __all__ = [
     "Contact",
     "ContactSystem",
     "ContactUse",
+    "ContentType",
     "Count",
     "Criticality",
+    "DSAKeyValueType",
+    "DateTimeType",
     "Device",
     "DeviceObservationReport",
     "DeviceObservationReport_Channel",
@@ -732,6 +775,7 @@ __all__ = [
     "DiagnosticReport",
     "DiagnosticReportStatus",
     "DiagnosticReport_Image",
+    "DigestMethodType",
     "Distance",
     "DocumentManifest",
     "DocumentMode",
@@ -751,6 +795,7 @@ __all__ = [
     "Encounter_Hospitalization",
     "Encounter_Location",
     "Encounter_Participant",
+    "EntryType",
     "EventTiming",
     "ExposureType",
     "Extension",
@@ -758,6 +803,7 @@ __all__ = [
     "FamilyHistory",
     "FamilyHistory_Condition",
     "FamilyHistory_Relation",
+    "FeedType",
     "FilterOperator",
     "Flow",
     "Group",
@@ -765,6 +811,7 @@ __all__ = [
     "Group_Characteristic",
     "HierarchicalRelationshipType",
     "HumanName",
+    "IdType",
     "Identifier",
     "IdentifierUse",
     "ImagingModality",
@@ -782,6 +829,8 @@ __all__ = [
     "Inline",
     "InstanceAvailability",
     "IssueSeverity",
+    "KeyInfoType",
+    "KeyValueType",
     "LinkType",
     "List",
     "ListMode",
@@ -790,6 +839,7 @@ __all__ = [
     "LocationMode",
     "LocationStatus",
     "Location_Position",
+    "ManifestType",
     "Media",
     "MediaType",
     "Medication",
@@ -823,6 +873,7 @@ __all__ = [
     "NameUse",
     "Narrative",
     "NarrativeStatus",
+    "ObjectType",
     "Observation",
     "ObservationRelationshipType",
     "ObservationReliability",
@@ -838,11 +889,13 @@ __all__ = [
     "Organization",
     "Organization_Contact",
     "Other",
+    "PGPDataType",
     "Patient",
     "Patient_Animal",
     "Patient_Contact",
     "Patient_Link",
     "Period",
+    "PersonType",
     "Practitioner",
     "Practitioner_Qualification",
     "Procedure",
@@ -876,9 +929,11 @@ __all__ = [
     "QuestionnaireStatus",
     "Questionnaire_Group",
     "Questionnaire_Question",
+    "RSAKeyValueType",
     "Range",
     "Ratio",
     "ReactionSeverity",
+    "ReferenceType",
     "RelatedPerson",
     "Resource",
     "ResourceProfileStatus",
@@ -888,6 +943,8 @@ __all__ = [
     "RestfulConformanceMode",
     "RestfulOperationSystem",
     "RestfulOperationType",
+    "RetrievalMethodType",
+    "SPKIDataType",
     "SampledData",
     "SampledDataDataType",
     "Schedule",
@@ -908,6 +965,12 @@ __all__ = [
     "SecurityEvent_Source",
     "SensitivityStatus",
     "SensitivityType",
+    "SignatureMethodType",
+    "SignaturePropertiesType",
+    "SignaturePropertyType",
+    "SignatureType",
+    "SignatureValueType",
+    "SignedInfoType",
     "SlicingRules",
     "Specimen",
     "Specimen_Collection",
@@ -921,7 +984,11 @@ __all__ = [
     "SupplyDispenseStatus",
     "SupplyStatus",
     "Supply_Dispense",
+    "TextType",
+    "TransformType",
+    "TransformsType",
     "UnitsOfTime",
+    "UriType",
     "ValueSet",
     "ValueSetStatus",
     "ValueSet_Compose",
@@ -931,6 +998,8 @@ __all__ = [
     "ValueSet_Expansion",
     "ValueSet_Filter",
     "ValueSet_Include",
+    "X509DataType",
+    "X509IssuerSerialType",
     "a",
     "a_content",
     "abbr",
@@ -952,6 +1021,7 @@ __all__ = [
     "dateTime",
     "dd",
     "decimal",
+    "deleted_entry",
     "dfn",
     "div",
     "dl",
@@ -971,6 +1041,7 @@ __all__ = [
     "integer",
     "kbd",
     "li",
+    "linkType",
     "map",
     "oid",
     "ol",
